@@ -12,7 +12,7 @@ class HSClient(object):
 
     '''
 
-    version = '3.1'     # SDK version
+    version = '3.2'     # SDK version
     API_VERSION = 'v3'  # API version
     API_URL = ''
 
@@ -1080,7 +1080,9 @@ class HSClient(object):
             "subject": subject, 
             "message": message,
             "signing_redirect_url": signing_redirect_url,
-            "form_fields_per_document": form_fields_per_document
+            "form_fields_per_document": form_fields_per_document,
+            "use_text_tags": self._boolean(use_text_tags),
+            "hide_text_tags": self._boolean(hide_text_tags)
         }
 
         # remove attributes with none value
